# Changelog

## 2.0.1 (2025-05-29)

Full Changelog: [v2.0.0...v2.0.1](https://github.com/bem-team/bem-sdk-python/compare/v2.0.0...v2.0.1)

### Chores

* update SDK settings ([9c3caf2](https://github.com/bem-team/bem-sdk-python/commit/9c3caf29b2616692a3c7b5a6f2438fe3f78ac9fe))
* update SDK settings ([e81264e](https://github.com/bem-team/bem-sdk-python/commit/e81264e1bbf63ab0cc7653bb6a8fa5f0ad58c8a3))

## 2.0.0 (2025-05-29)

Full Changelog: [v1.0.0...v2.0.0](https://github.com/bem-team/bem-sdk-python/compare/v1.0.0...v2.0.0)

### Features

* **api:** update via SDK Studio ([77e6d10](https://github.com/bem-team/bem-sdk-python/commit/77e6d10a59fb7046a27229b3fe11794836d556ae))
* **api:** update via SDK Studio ([725f30d](https://github.com/bem-team/bem-sdk-python/commit/725f30d5776594f284be14b7f8d6b2c389991e95))
* **api:** update via SDK Studio ([3647cee](https://github.com/bem-team/bem-sdk-python/commit/3647ceef0fe7943f677b02b46ef7d1a52c19d8e9))
* **api:** update via SDK Studio ([194982b](https://github.com/bem-team/bem-sdk-python/commit/194982bea3bf6eb99df93ad646fc9f7e03f94a95))


### Chores

* **internal:** version bump ([d60474a](https://github.com/bem-team/bem-sdk-python/commit/d60474ad44b340a7f28a7d8faa91c0fb04098e80))
* remove custom code ([b585ebb](https://github.com/bem-team/bem-sdk-python/commit/b585ebbca9164d7d867b2bc7ceec04b28119cbbb))

## 1.0.0 (2025-05-29)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/bem-team/bem-sdk-python/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* configure new SDK language ([5f51784](https://github.com/bem-team/bem-sdk-python/commit/5f517844a08d801af0a5ad6fc4c36260202c2164))
* update SDK settings ([1e5fcd9](https://github.com/bem-team/bem-sdk-python/commit/1e5fcd99b9e42679de48d3fdeed4f97e736e0782))
